@@ -1,4 +1,4 @@
-/*  $Id: xfcesmart.c 3719 2007-12-16 21:24:14Z afb $
+/*  $Id: xfcesmart.c 4615 2008-04-18 15:25:52Z afb $
  *
  *  xfce4-smartpm-plugin - a package manager applet for the xfce4 panel
  *  Copyright (c) 2007 Anders F Bjorklund <afb@users.sourceforge.net>
@@ -690,7 +690,11 @@ smart_sudo_smart_gui(SmartPlugin *smart, gchar *args)
     case PACKAGE_MANAGER_SMART:
       if (smart_program_exists("/usr/sbin/" SMART_SUIDBIN))
         program = g_strdup("/usr/sbin/" SMART_SUIDBIN);
-      else if (smart_program_exists(PATH_GKSUDO))
+      else if (smart_program_exists("/usr/bin/" SMART_SUIDBIN))
+        program = g_strdup("/usr/bin/" SMART_SUIDBIN);
+      else if (smart->su_instead_of_sudo && smart_program_exists(PATH_GKSU))
+        program = g_strdup_printf("%s -- %s", PATH_GKSU, SMART_PROGRAM);
+      else if (!smart->su_instead_of_sudo && smart_program_exists(PATH_GKSUDO))
         program = g_strdup_printf("%s -- %s", PATH_GKSUDO, SMART_PROGRAM);
       else
         program = g_strdup(SMART_PROGRAM);
@@ -843,6 +847,7 @@ smart_save (XfcePanelPlugin *plugin,
       xfce_rc_write_int_entry (rc, "manager", smart->package_manager);
       xfce_rc_write_bool_entry (rc, "appicon", smart->show_application);
       xfce_rc_write_bool_entry (rc, "notify", smart->show_notifications);
+      xfce_rc_write_bool_entry (rc, "su", smart->su_instead_of_sudo);
 
       /* close the rc file */
       xfce_rc_close (rc);
@@ -877,6 +882,7 @@ smart_read (SmartPlugin *smart)
           smart->package_manager = xfce_rc_read_int_entry (rc, "manager", PACKAGE_MANAGER_SMART);
           smart->show_application =  xfce_rc_read_bool_entry (rc, "appicon", TRUE);
           smart->show_notifications =  xfce_rc_read_bool_entry (rc, "notify", FALSE);
+          smart->su_instead_of_sudo =  xfce_rc_read_bool_entry (rc, "su", FALSE);
 
           /* cleanup */
           xfce_rc_close (rc);
@@ -895,6 +901,7 @@ smart_read (SmartPlugin *smart)
   smart->package_manager = PACKAGE_MANAGER_SMART;
   smart->show_application = TRUE;
   smart->show_notifications = FALSE;
+  smart->su_instead_of_sudo = FALSE;
 }
 
 
@@ -1032,7 +1039,7 @@ smart_checkbox3_toggle_cb(GtkToggleButton *button,
 {
   SmartPlugin *smart = user_data;
 
-  smart->upgrade_directly = gtk_toggle_button_get_active(button);
+  smart->su_instead_of_sudo = gtk_toggle_button_get_active(button);
 }
 
 static void
@@ -1041,6 +1048,15 @@ smart_checkbox4_toggle_cb(GtkToggleButton *button,
 {
   SmartPlugin *smart = user_data;
 
+  smart->upgrade_directly = gtk_toggle_button_get_active(button);
+}
+
+static void
+smart_checkbox5_toggle_cb(GtkToggleButton *button,
+        gpointer user_data)
+{
+  SmartPlugin *smart = user_data;
+
   smart->dist_upgrade = gtk_toggle_button_get_active(button);
 }
 
@@ -1473,16 +1489,22 @@ smart_configure (XfcePanelPlugin *plugin,
   gtk_widget_set_sensitive (button, FALSE);
 #endif
   
+  button = gtk_check_button_new_with_label(_("Use su for authentication (instead of sudo)"));
+  gtk_widget_show (button);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), smart->su_instead_of_sudo);
+  g_signal_connect (G_OBJECT(button),"toggled", G_CALLBACK(smart_checkbox3_toggle_cb), smart);
+  gtk_box_pack_start (GTK_BOX(vbox),button,TRUE,TRUE,0);
+
   button = gtk_check_button_new_with_label(_("Upgrade on launch (if upgrades available)"));
   gtk_widget_show (button);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), smart->upgrade_directly);
-  g_signal_connect (G_OBJECT(button),"toggled", G_CALLBACK(smart_checkbox3_toggle_cb), smart);
+  g_signal_connect (G_OBJECT(button),"toggled", G_CALLBACK(smart_checkbox4_toggle_cb), smart);
   gtk_box_pack_start (GTK_BOX(vbox),button,TRUE,TRUE,0);
 
   button = gtk_check_button_new_with_label(_("Smart upgrade to newer release (dist-upgrade)"));
   gtk_widget_show (button);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), smart->dist_upgrade);
-  g_signal_connect (G_OBJECT(button),"toggled", G_CALLBACK(smart_checkbox4_toggle_cb), smart);
+  g_signal_connect (G_OBJECT(button),"toggled", G_CALLBACK(smart_checkbox5_toggle_cb), smart);
   gtk_box_pack_start (GTK_BOX(vbox),button,TRUE,TRUE,0);
 
   g_object_set_data (G_OBJECT (plugin), "dist-upgrade", button);
